FileTransit - Software Downloads, News, Reviews and More!
Description: Shareware, Freeware and Demo Software, Scripts including categories such as desktop, audio, graphics, business, programming, email, internet, asp, php, cgi, macintosh, linux. All software, scripts can be downloaded and tested for free!
Keywords: download,software,scripts,shareware,freeware,games,business,desktop,audio,asp,cgi,php,linux,macintosh,beos,os2

Home | About Us | Link To Us | FAQ | Contact

Serving Software Downloads in 976 Categories, Downloaded 25.800.637 Times

Featured | New | Popular | Top Rated | Reviews | Index | Submit

Windows Software | BeOS Software
Macintosh Software | Linux Software
PDA Software | OS/2 Software
MS-DOS Software | Scripts
Mobile

3963 - VB Decompiler 945 - Remote Process Viewer 658 - RapidTyping Typing Tutor 593 - CoffeeCup HTML Editor 547 - POS Software Imonggo 473 - MathCast Equation Editor 374 - Atlantis Word Processor 353 - Revo Uninstaller 337 - Comodo Firewall 230 - Freo Messenger 193 - CyberBrowser 186 - Lobby Track Access Control Software 67 - opentaps open source ERP+CRM
2014.12.04 - Dr.Web CureIt 2014.12.04 - DrawWiz - Elf Camera 2014.12.04 - Super Screen Clean 2014.12.04 - Calus 2014.12.04 - CloudBacko Lite for Mac 2014.12.04 - Real Hide IP 2014.12.04 - Free Video To Audio Converter 2014 2014.12.04 - Abettor Clipboard 2014.12.04 - Quick Image Resizer 2014.12.04 - Comfy Hotel Reservation 2014.12.04 - Express Points Presentation Maker Free 2014.12.04 - AOMEI Partition Assistant Server Edition 2014.12.04 - AnyMP4 MP3 Converter for Mac 2014.12.04 - Power Burning Wizard 2014.12.04 - NTFS Security Management Suite 2014 2014.12.04 - PDF Focus .Net 2014.12.04 - Soft4Boost Screen Recorder 2014.12.04 - PostgresToMysql 2014.12.04 - Aml Pages Portuguese version 2014.12.04 - Aiseesoft Blu-ray Creator
Tary - Well, this is an exceptionally good program.... Verdone Oxford - The program works very well. Easy to use for you! Peaches - I've used this software for years and love it. Wang - Pretty good tool. Made remote computing easy... Malik - It's a very helpful utility to root android... Beekman - Great program for deleting invalid and broken... Grumet Bellman - It has helped me very much. I highly recommend... Sunil - Doesn't work good as I thought. Montag Workman - Thanks to the clear-cut and convenient... Haycraft Voorhees - Great program that's consistently performed...

1. Remote Desktop Tool
2. PCMate Free File Encryptor
3. Webcam/Screen Video Capture Free
4. Free WiFi Router
5. Easy Gift Card
6. Capture-A-ScreenShot
7. Holiline Reminder
8. SyncMate
9. Bitdefender Internet Security
10. Crazy Tennis

Welcome to The File Transit, we are a software distribution site with thousands of high quality applications and games. We support over 25 Operating Systems and hold thousands of titles which are carefully placed in hundreds of relevant categories. We make updates several times daily to ensure the freshest content possible.

Recent products

#

Dr.Web CureIt 9.1
Released: December 12, 2013 | Added: December 04, 2014 | Visits: 75

Do you have anti-virus software installed on your computer, but still worry about its effectiveness? Run Dr.Web CureIt! (no need to install it) to quickly scan your computer and cure it of any malicious objects. Dr.Web CureIt is an indispensable tool for curing computers running MS...
Platforms: Windows 2000, Windows XP, Windows 8, Win7 x32, Win7 x64, WinServer, Windows Vista

License: Freeware | Size: 149.84 MB | Download (1): Dr.Web CureIt Download

DrawWiz - Elf Camera 1.0
Released: November 28, 2014 | Added: December 04, 2014 | Visits: 71

DrawWiz - Elf Camera Create your own elf and bring it into your real life DrawWiz lets you travel through time to 5 dimensional space. You can instantly expand your real live and access the fantasy experience in the literature or science fiction movies. Combine scenes of real world with...
Platforms: Android

License: Freeware | Size: 38 MB | Download (1): DrawWiz - Elf Camera Download

Super Screen Clean 1.2.0
Released: December 02, 2014 | Added: December 04, 2014 | Visits: 68

Do you ever have the uncomfortable feeling that somebody is watching over your shoulder while you're using the Internet? Perhaps it's your Boss, or perhaps it's a member of your family? When they come by, you might want a quick and easy way to clean all the windows off your desktop,...
Platforms: Win7 x32, Win7 x64, WinOther, WinServer, Windows Vista, Other

License: Shareware | Cost: $74.95 USD | Size: 2.5 MB | Download (5): Super Screen Clean Download

Calus 4.7
Released: October 28, 2014 | Added: December 04, 2014 | Visits: 62

The program allows you to manage materials in a warehouse with loads, unloads and return. Once you have entered your inventory items, you can move them in entry (loads), output (unload) or return by the customer (return). The window that allows the movement is very simple and allows you to...
Platforms: Windows XP, Windows 8, Win7 x32, Win7 x64, WinServer, Windows Vista

License: Demo | Cost: $32.50 USD | Size: 8.92 MB | Download (1): Calus Download

CloudBacko Lite for Mac 1.7.2.0
Released: November 18, 2014 | Added: December 04, 2014 | Visits: 61

CloudBackup Lite is an easy to use cloud and local backup software designed for backing up files in Mac OS X. It supports backing up data to Amazon S3, Google Cloud Storage, Google Drive, Microsoft Azure, Microsoft OneDrive, Rackspace, OpenStack, Dropbox, FTP/SFTP sites, and local drives....
Platforms: Mac OSX

License: Shareware | Cost: $9.00 USD | Size: 160.78 MB | Download (1): CloudBacko Lite for Mac Download

Real Hide IP 4.4.2.8
Released: November 13, 2014 | Added: December 04, 2014 | Visits: 10.637

Real Hide IP is easy-to-use privacy software which allows you to conceal your IP address, choose IP country and surf anonymously. It can protect your privacy, prevent identity theft, and guard against cyber crimer intrusions, all with the click of a button. Using it, you can conceal your...
Platforms: Windows 2000, Windows XP, Win7 x32, Win7 x64, Windows Vista

License: Shareware | Cost: $19.95 USD | Size: 2.31 MB | Download (619): Real Hide IP Download

Free Video To Audio Converter 2014 4.1.5
Released: November 19, 2014 | Added: December 04, 2014 | Visits: 509

Free Video to Audio Converter is a powerful audio extractor extracting audio from video, like convert MPEG to MP3, convert MPEG to M4A, and AVI to MP3. The primary function of the video to audio converter is extracting audio from video files, such as convert AVI to MP3, and convert MPEG, WMV,...
Platforms: Windows 98, Windows XP, WinOther, WinServer, Windows Vista

License: Freeware | Size: 4.42 MB | Download (149): Free Video To Audio Converter 2014 Download

Abettor Clipboard 4.43
Released: December 03, 2014 | Added: December 04, 2014 | Visits: 2.060

Abettor-Clipboard can copy and store up to 500 different clips, text or graphic. It has a superb encryption system with which you can sign in to all your web sites as well as send and recieve encrypted emails while only having to remember one master password. You can also allocate hot keys or...
Platforms: Windows 98, Windows 2000, Windows XP, Win7 x32, Win7 x64, WinOther, WinServer, Windows Vista

License: Freeware | Size: 6.46 MB | Download (10): Abettor Clipboard Download

Quick Image Resizer 2.7.3.1
Released: November 26, 2014 | Added: December 04, 2014 | Visits: 1.731

Modern digital cameras produce images with up to 6 times higher resolution than their ancestors. While the resolution is very important to photo-printers, such resolution can be a severe drawback for on-screen and Internet viewing. This is why, before uploading your images to the Web or sending...
Platforms: Windows 95, Windows 98, Windows 2000, Windows XP, Windows 2003, Windows Vista, Windows 8, Win7 x32, Win7 x64, WinServer, Windows Tablet PC Edition 2005,Windows Media Center Edition 2005

License: Shareware | Cost: $29.00 USD | Size: 2.92 MB | Download (159): Quick Image Resizer Download

Comfy Hotel Reservation 4.6
Released: December 02, 2014 | Added: December 04, 2014 | Visits: 2.944

Comfy Hotel Reservation assists hotels, apartments, b&b accommodations, motels, guest-houses or holiday homes in managing and maintaining reservations. The system is fully scalable and designed to provide extensive flexibility and varied choices. Hotels and travel agents can achieve maximum time...
Platforms: Windows 2000, Windows XP, Win7 x32, Win7 x64, WinServer, Windows Vista

License: Shareware | Cost: $49.95 USD | Size: 9.76 MB | Download (228): Comfy Hotel Reservation Download

Express Points Presentation Maker Free 1.13
Released: November 03, 2014 | Added: December 04, 2014 | Visits: 99

Express Points Free Presentation Software for Windows. Design multimedia presentations for your meetings or events. Raise communication effectiveness and make your points more compelling with text, music, narration, images and graphic shapes. Express Points can make delivering explanatory and...
Platforms: Windows XP, Windows 8, Win7 x32, Win7 x64, Windows Vista

License: Freeware | Size: 1.26 MB | Download (7): Express Points Presentation Maker Free Download

AOMEI Partition Assistant Server Edition 5.6
Released: November 28, 2014 | Added: December 04, 2014 | Visits: 878

AOMEI Partition Assistant Server Edition is all-in-one multilingual server disk partition software which could assist you to optimize your server disk performance. With its help, you can safely extend system partition, easily allocate free space, quickly migrate OS to other disk,...
Platforms: Windows 2000, Windows XP, Windows 2003, Win7 x32, Win7 x64, WinServer, Windows Vista

License: Demo | Cost: $139.00 USD | Size: 18.77 MB | Download (91): AOMEI Partition Assistant Server Edition Download

AnyMP4 MP3 Converter for Mac 6.0.70
Released: November 30, 2013 | Added: December 04, 2014 | Visits: 387

AnyMP4 MP3 Converter for Mac is the professional MP3 Converting software, which can not only convert any audio to MP3, AAC, AIFF, ALAC, WAV and M4A, but also extract audios from the video files and then convert them to MP3, AAC, ALAC, etc. Besides, you can use this software to trim the audio to...
Platforms: Mac OSX, Mac Other,Other

License: Shareware | Cost: $19.00 USD | Size: 25.7 MB | Download (53): AnyMP4 MP3 Converter for Mac Download

Power Burning Wizard 5.3.1
Released: November 25, 2014 | Added: December 04, 2014 | Visits: 3.484

Power Burning Wizard is a powerful tool for grabbing, burning and mastering CD, DVD, Blu-Ray and HD-DVD media. Power Burning Wizard supports all types of optical storage media (including CD-R/RW, DVD-R/RW, DVD+R/RW, BD-R/RE, HD-DVD-R/RW and DVD-RAM) as well as a wide variety of burning hardware....
Platforms: Windows 2000, Windows XP, Win7 x32, Win7 x64, WinOther, WinServer, Windows Vista

License: Shareware | Cost: $29.95 USD | Size: 4.83 MB | Download (695): Power Burning Wizard Download

NTFS Security Management Suite 2014 2014
Released: June 26, 2014 | Added: December 04, 2014 | Visits: 101

The NTFS Security Management Suite 2014 is a packaged solution offering the combined potential of NTFS Security Auditor and the NTFS Security Manager. While the Auditor helps Windows administrators with security audit reports, the Manager helps them copy, modify or create new permissions by...
Platforms: Windows XP, Windows 8, Windows Server, Win7 x32, Win7 x64, Windows Vista

License: Commercial | Cost: $1299.00 USD | Size: 17.7 MB | Download (18): NTFS Security Management Suite 2014 Download

PDF Focus .Net 5.0.12
Released: December 01, 2014 | Added: December 04, 2014 | Visits: 1.845

.Net library for converting PDF documents to Word, RTF, HTML, XML, Text and Images, JPEG, PNG, and multipage-TIFF. Entirely created in C# and can be used in any .Net app: WinForms C#, WPF, VB.Net, Silverlight, and ASP.Net. The library is totally written in managed C#, it's absolutely...
Platforms: Windows XP, WinServer, Windows Vista

License: Shareware | Cost: $578.00 USD | Size: 16.75 MB | Download (247): PDF Focus .Net Download

Soft4Boost Screen Recorder 3.1.3.145
Released: November 30, 2014 | Added: December 04, 2014 | Visits: 381

Soft4Boost Screen Recorder is a simple to use utility which allows you to record all the operations you perform with the mouse and anything you see on your computer screen within the selected area. Soft4Boost Screen Recorder allows you to create video tutorials, prepare a college project,...
Platforms: Windows XP, Windows 2003, Windows Vista, Win7 x32, Win7 x64

License: Shareware | Cost: $24.95 USD | Size: 41.03 MB | Download (29): Soft4Boost Screen Recorder Download

PostgresToMysql 1.2
Released: November 07, 2014 | Added: December 04, 2014 | Visits: 323

PostgresToMysql - Import PostgreSQL to MySQL. PostgresToMysql is a data conversion tool that helps database user to convert PostgreSQL data to MySQL database. The main features are: 1. Easy visual configuration -- just click on the mouse. 2. Displays progress through time estimation. 3....
Platforms: Windows 2000, Windows XP, Windows 2003, Windows 8, Windows Server, Win7 x32, Win7 x64, WinServer, Windows Vista

License: Shareware | Cost: $129.00 USD | Size: 5.79 MB | Download (26): PostgresToMysql Download

Aml Pages Portuguese version 9.58
Released: December 01, 2014 | Added: December 04, 2014 | Visits: 790

Aml Pages is tree-structured notes manager for Windows. It contains all your notes, information, web pages, passwords, URL-address in the form of a tree, so you can quickly find what you need. Manage megatons of your notes with ease at work and at home. Why I need it on my PC? Have you ever...
Platforms: Windows 2000, Windows XP, Win7 x32, Win7 x64, WinOther, WinServer, Windows Vista

License: Shareware | Cost: $29.00 USD | Size: 3.66 MB | Download (74): Aml Pages Portuguese version Download

Aiseesoft Blu-ray Creator 1.0.62
Released: November 30, 2014 | Added: December 04, 2014 | Visits: 285

Aiseesoft Blu-ray Creator has the ability to create Blu-ray disc(BD-25 and BD-50), Blu-ray folder and ISO files from M2TS, TS, TRP, TP, MGP, MPEG, MPA, VOB, DAT, MP4, M4V, RM, RMVB, WMV, ASF, MKV, AVI, 3GP, MPV, MOD, TOD, QT, MOV, DV, DIF, MJPG, MJPEG video formats. What' s more, it also provides...
Platforms: Windows 2000, Windows XP, Win7 x32, Win7 x64, WinOther, Windows Vista, Other

License: Shareware | Cost: $27.00 USD | Size: 36.4 MB | Download (61): Aiseesoft Blu-ray Creator Download

Home | About Us | Privacy | Disclaimer | Link to Us | Contact Us | Top Searches | Submit Software
File Transit © 1998-2014